.. _api-filestore:

job.fileStore API
*****************

The AbstractFileStore is an abstraction of a Toil run's shared storage.

.. autoclass:: toil.fileStores.abstractFileStore::AbstractFileStore
   :members:
   :noindex:

.. autoclass:: toil.fileStores::FileID
   :members:
   :noindex:
